@@ -709,9 +709,9 @@ function _M.plugin_checker(item, schema_type)
 end
 
 
-function _M.stream_plugin_checker(item)
+function _M.stream_plugin_checker(item, in_cp)
     if item.plugins then
-        return stream_check_schema(item.plugins, nil, true)
+        return stream_check_schema(item.plugins, nil, not in_cp)
     end
 
     return true
@@ -736,20 +736,11 @@ function _M.run_plugin(phase, plugins, api_ctx)
         and phase ~= "delayed_body_filter"
     then
         for i = 1, #plugins, 2 do
-            local phase_func
-            if phase == "rewrite_in_consumer" then
-                if plugins[i].type == "auth" then
-                    plugins[i + 1]._skip_rewrite_in_consumer = true
-                end
-                phase_func = plugins[i]["rewrite"]
-            else
-                phase_func = plugins[i][phase]
+            if phase == "rewrite_in_consumer" and plugins[i + 1]._from_consumer
+                    and plugins[i].type ~= "auth"then
+                phase = "rewrite"
             end
-
-            if phase == "rewrite_in_consumer" and plugins[i + 1]._skip_rewrite_in_consumer then
-                goto CONTINUE
-            end
-
+            local phase_func = plugins[i][phase]
             if phase_func then
                 plugin_run = true
                 local code, body = phase_func(plugins[i + 1], api_ctx)
@@ -769,8 +760,6 @@ function _M.run_plugin(phase, plugins, api_ctx)
                     end
                 end
             end
-
-            ::CONTINUE::
         end
         return api_ctx, plugin_run
     end
