@@ -16,10 +16,15 @@
 --
 local core        = require("apisix.core")
 local expr        = require("resty.expr.v1")
+local re_compile  = require("resty.core.regex").re_match_compile
 local plugin_name = "response-rewrite"
 local ngx         = ngx
+local re_sub      = ngx.re.sub
+local re_gsub     = ngx.re.gsub
 local pairs       = pairs
+local ipairs      = ipairs
 local type        = type
+local pcall       = pcall
 
 
 local schema = {
@@ -48,6 +53,40 @@ local schema = {
         vars = {
             type = "array",
         },
+        filters = {
+            description = "a group of filters that modify response body" ..
+                          "by replacing one specified string by another",
+            type = "array",
+            minItems = 1,
+            items = {
+                description = "filter that modifies response body",
+                type = "object",
+                required = {"regex", "replace"},
+                properties = {
+                    regex = {
+                        description = "match pattern on response body",
+                        type = "string",
+                        minLength = 1,
+                    },
+                    scope = {
+                        description = "regex substitution range",
+                        type = "string",
+                        enum = {"once", "global"},
+                        default = "once",
+                    },
+                    replace = {
+                        description = "regex substitution content",
+                        type = "string",
+                    },
+                    options = {
+                        description = "regex options",
+                        type = "string",
+                        default = "jo",
+                    }
+                },
+            },
+        },
+        oneOf = {"body", "filters"},
     },
     minProperties = 1,
 }
@@ -115,6 +154,16 @@ function _M.check_schema(conf)
         end
     end
 
+    if conf.filters then
+        for _, filter in ipairs(conf.filters) do
+            local ok, err = pcall(re_compile, filter.regex, filter.options)
+            if not ok then
+                return false, "regex \"" .. filter.regex ..
+                        "\" validation failed: "  .. err
+            end
+        end
+    end
+
     return true
 end
 
@@ -126,6 +175,29 @@ function _M.body_filter(conf, ctx)
         return
     end
 
+    if conf.filters then
+
+        local body = core.response.hold_body_chunk(ctx)
+        if not body then
+            return
+        end
+
+        local err
+        for _, filter in ipairs(conf.filters) do
+            if filter.scope == "once" then
+                body, _, err = re_sub(body, filter.regex, filter.replace, filter.options)
+            else
+                body, _, err = re_gsub(body, filter.regex, filter.replace, filter.options)
+            end
+            if err ~= nil then
+                core.log.error("regex \"" .. filter.regex .. "\" substitutes failed:" .. err)
+            end
+        end
+
+        ngx.arg[1] = body
+        return
+    end
+
     if conf.body then
 
         if conf.body_base64 then
@@ -148,7 +220,8 @@ function _M.header_filter(conf, ctx)
         ngx.status = conf.status_code
     end
 
-    if conf.body then
+    -- if filters have no any match, response body won't be modified.
+    if conf.filters or conf.body then
         core.response.clear_header_as_body_modified()
     end
 
